@@ -21,14 +21,14 @@ namespace Rivet {
     /// @name Analysis methods
     /// @{
 
-    /// @brief Calculate angular distance between particles.
-    double phaseDif(double a1, double a2, const pair<double, double>& edges) {
-      double dif = a1 - a2;
-      while (dif < edges.first)
-        dif += 2*M_PI;
-      while (dif > edges.second)
-        dif -= 2*M_PI;
-      return dif;
+    /// @brief Calculate angular distance between particles,
+    /// return index of corresponding discrete bin
+    size_t discPhi(double a1, double a2, const YODA::Axis<double>& axis) const {
+      double diff = a1 - a2;
+      while (diff < axis.min(1))               diff += 2*M_PI;
+      while (diff > axis.max(axis.numBins()))  diff -= 2*M_PI;
+      size_t idx = axis.index(diff);
+      return idx > axis.numBins()? 0 : idx;
     }
 
 
@@ -65,6 +65,17 @@ namespace Rivet {
       vector<string> refdata = {"d04-x01-y01","d04-x01-y02","d04-x01-y03",
         "d06-x01-y02","d05-x01-y01","d05-x01-y02","d05-x01-y03","d06-x01-y01",
         "d01-x01-y02","d02-x01-y02"};
+      _axes.resize(3);
+      _axes[0] = YODA::Axis<double>({-1.46, -1.19, -0.97, -0.76, -0.54, -0.33, -0.11, 0.11, 0.33, 0.54,
+                                      0.76,  0.98,  1.19,  1.41,  1.62,  1.84,  2.06, 2.27, 2.49, 2.71,
+                                      2.92,  3.14,  3.36,  3.58,  3.79,  4.01,  4.22, 4.44, 4.66, 4.77});
+      _axes[1] = YODA::Axis<double>({-1.46, -1.19, -0.97, -0.76, -0.54, -0.33, -0.11, 0.11, 0.33, 0.54,
+                                      0.76, 0.98, 1.19, 1.41, 1.62, 1.84, 2.06, 2.27, 2.49, 2.71, 2.92,
+                                      3.14, 3.36, 3.58, 3.79, 4.01, 4.22, 4.44, 4.66, 4.77});
+      _axes[2] = YODA::Axis<double>({-1.14, -0.95, -0.69, -0.41, -0.14, 0.14, 0.41, 0.68, 0.96, 1.23,
+                                      1.50,  1.77,  2.05,  2.33,  2.59, 2.87, 3.14, 3.42, 3.68, 3.96,
+                                      4.24, 4.50, 4.78, 4.92});
+
       // Resize all the analysis object containers to right size.
       ratio.resize(refdata.size());
       signal.resize(refdata.size());
@@ -72,7 +83,7 @@ namespace Rivet {
       nsp.resize(refdata.size());
       nmp.resize(refdata.size());
       for (int i = 0, N = refdata.size(); i < N; ++i) {
-        const YODA::Estimate1D& tmp = refData(refdata[i]);
+        const auto& tmp = refData<YODA::BinnedEstimate<string>>(refdata[i]);
         // The ratio plots.
         book(ratio[i], refdata[i]);
         // Signal and mixed background should not be displayed.
@@ -81,32 +92,31 @@ namespace Rivet {
         // Number of signal and mixed pairs for normalization.
         book(nsp[i],"TMP/nsp"+std::to_string(i));
         book(nmp[i],"TMP/nmp"+std::to_string(i));
-        // The differing deltaphi histogram edges per pair.
-        deltaphi.push_back({tmp.xMin(), tmp.xMax()});
       }
     }
 
 
-    void fillPair(const Particle& p1, const Particle& p2, vector<Histo1DPtr>& histos,
-      vector<CounterPtr>& sow) {
-	   if (isSame(p1,p2)) return;
-          // If the pair is not within eta acceptance, we can continue early.
-          if (abs(p1.eta() - p2.eta()) > 1.3) return;
-          // Figure out which pid pair we are looking at.
-          int iPair = -1;
-          for (int i = 0, N = pid.size(); i < N; ++i) {
-            if (pid[i].first == p1.pid() && pid[i].second == p2.pid()) {
-              iPair = i;
-              break;
-            }
-          }
-          // If the pair is not in the analysis, don't fill anything.
-          if (iPair < 0) return;
-          // Apply min pT cuts, varies for different species.
-          if (p1.pT() < pTcuts[iPair].first || p2.pT() < pTcuts[iPair].second) return;
-          const double dPhi = phaseDif(p1.phi(), p2.phi(), deltaphi[iPair]);
-          histos[iPair]->fill(dPhi);
-          sow[iPair]->fill();
+    void fillPair(const Particle& p1, const Particle& p2, vector<BinnedHistoPtr<string>>& histos, vector<CounterPtr>& sow) {
+	    if (isSame(p1,p2)) return;
+      // If the pair is not within eta acceptance, we can continue early.
+      if (abs(p1.eta() - p2.eta()) > 1.3) return;
+      // Figure out which pid pair we are looking at.
+      int iPair = -1;
+      for (int i = 0, N = pid.size(); i < N; ++i) {
+        if (pid[i].first == p1.pid() && pid[i].second == p2.pid()) {
+          iPair = i;
+          break;
+        }
+      }
+      // If the pair is not in the analysis, don't fill anything.
+      if (iPair < 0) return;
+      // Apply min pT cuts, varies for different species.
+      if (p1.pT() < pTcuts[iPair].first || p2.pT() < pTcuts[iPair].second) return;
+      size_t axis_id = iPair < 3? 0 : 2;
+      if (4 <= iPair && iPair <= 6)  axis_id = 1;
+      size_t idx = discPhi(p1.phi(), p2.phi(), _axes[axis_id]);
+      histos[iPair]->fill(idx? histos[iPair]->bin(idx).xEdge() : "OTHER"s);
+      sow[iPair]->fill();
     }
 
 
@@ -151,14 +161,14 @@ namespace Rivet {
     /// Analysis variables.
     vector<pair<int, int> > pid;
     vector<pair<double, double> > pTcuts;
-    vector<pair<double, double> > deltaphi;
     /// @name Histograms and counters
     /// @{
-    vector<Histo1DPtr> signal;
-    vector<Histo1DPtr> background;
-    vector<Estimate1DPtr> ratio;
+    vector<BinnedHistoPtr<string>> signal;
+    vector<BinnedHistoPtr<string>> background;
+    vector<BinnedEstimatePtr<string>> ratio;
     vector<CounterPtr> nsp;
     vector<CounterPtr> nmp;
+    vector<YODA::Axis<double>> _axes;
 
     /// @}
 
