@@ -29,7 +29,7 @@ namespace Rivet {
 
         size_t offset = is7TeV? 10 : 6;
         for (size_t ix=0; ix<4; ++ix) {
-          const string mode = en+toString(ix+1);
+          const string mode = en+toString(ix);
           book(_h[mode+"ratio_num"], "TMP/h_ratio_num_"+mode, refData(offset+ix,1,1));
           book(_h[mode+"ratio_den"], "TMP/h_ratio_den_"+mode, refData(offset+ix,1,1));
           book(_h[mode+"energy"],    "h_energy_"+mode,        refData(offset+ix,1,1));
@@ -61,7 +61,7 @@ namespace Rivet {
           continue;
         }
         // prompt at 5.02 TeV
-        if (_sqs == "7000"s) {
+        if (_sqs == "5020"s) {
           _h[_sqs+toString(imeson)+"prompt"]->fill(pT);
           _total->fill(_edges[imeson]);
         }
@@ -91,13 +91,13 @@ namespace Rivet {
     void finalize() {
       const double factor = crossSection()/microbarn/sumOfWeights();
       scale(_total, factor);
-      scale(_h,factor);
+      scale(_h, factor);
 
       Estimate1DPtr tmp;
       for (double eVal : allowedEnergies()) {
         const string en = toString(int(eVal/GeV));
         for (size_t ix=0; ix<4; ++ix) {
-          const string mode = en+toString(ix+1);
+          const string mode = en+toString(ix);
           bool is7TeV(en == "7000"s);
           book(tmp, 6+4*is7TeV+ix, 1, 1);
           divide(_h[mode+"ratio_num"], _h[mode+"ratio_den"], tmp);
