@@ -140,7 +140,7 @@ namespace Rivet {
         if (E == 200) {
           // If the 200 MeV pass, take the biggest of the two gaps. Make note of which side for higher pT cuts.
           largestEdgeGap = std::max(EdgeGapSizeA,EdgeGapSizeC);
-          gapDirectionAt200 = (EdgeGapSizeA > EdgeGapSizeC);
+          gapDirectionAt200 = fuzzyLessEquals(EdgeGapSizeC, EdgeGapSizeA);
         } else {
           // Use the direction from 200 MeV pass, most accurate measure of which side gap is on.
           if (gapDirectionAt200) {
