@@ -7,6 +7,7 @@
 #include "Rivet/Projections/IdentifiedFinalState.hh"
 #include "Rivet/Projections/UnstableParticles.hh"
 #include "Rivet/Projections/FastJets.hh"
+#include "Rivet/Tools/Random.hh"
 
 namespace Rivet {
 
@@ -15,8 +16,7 @@ namespace Rivet {
   public:
 
     /// Constructor
-    ATLAS_2012_I1204447()
-      : Analysis("ATLAS_2012_I1204447") {  }
+    RIVET_DEFAULT_ANALYSIS_CTOR(ATLAS_2012_I1204447);
 
 
     /// Book histograms and initialise projections before the run
@@ -25,9 +25,6 @@ namespace Rivet {
       // To calculate the acceptance without having the fiducial lepton efficiencies included, this part can be turned off
       _use_fiducial_lepton_efficiency = true;
 
-      // Random numbers for simulation of ATLAS detector reconstruction efficiency
-      srand(160385);
-
       // Read in all signal regions
       _signal_regions = getSignalRegions();
 
@@ -48,7 +45,7 @@ namespace Rivet {
       // Final state including all AntiKt 04 Jets
       VetoedFinalState vfs;
       vfs.addVetoPairId(PID::MUON);
-      declare(FastJets(vfs, FastJets::ANTIKT, 0.4), "AntiKtJets04");
+      declare(FastJets(vfs, JetAlg::ANTIKT, 0.4), "AntiKtJets04");
 
       // Final state including all unstable particles (including taus)
       declare(UnstableParticles(Cuts::abseta < 5.0 && Cuts::pT > 5*GeV), "UFS");
@@ -108,9 +105,9 @@ namespace Rivet {
 
         // Apply reconstruction efficiency and simulate reco
         int muon_id = 13;
-        if ( mu.hasAncestor(15) || mu.hasAncestor(-15)) muon_id = 14;
+        if ( mu.hasAncestorWith(Cuts::pid == 15) || mu.hasAncestorWith(Cuts::pid == -15)) muon_id = 14;
         const double eff = (_use_fiducial_lepton_efficiency) ? apply_reco_eff(muon_id, mu) : 1.0;
-        const bool keep_muon = rand()/static_cast<double>(RAND_MAX) <= eff;
+        const bool keep_muon = rand01() <= eff;
 
         // Keep muon if pTCone30/pT < 0.15 and eTCone30/pT < 0.2 and reconstructed
         if (keep_muon && pTinCone/mu.pT() <= 0.15 && eTinCone/mu.pT() < 0.2)
@@ -139,9 +136,9 @@ namespace Rivet {
 
         // Apply reconstruction efficiency and simulate reco
         int elec_id = 11;
-        if (e.hasAncestor(15) || e.hasAncestor(-15)) elec_id = 12;
+        if (e.hasAncestorWith(Cuts::pid == 15) || e.hasAncestorWith(Cuts::pid == -15)) elec_id = 12;
         const double eff = (_use_fiducial_lepton_efficiency) ? apply_reco_eff(elec_id, e) : 1.0;
-        const bool keep_elec = rand()/static_cast<double>(RAND_MAX) <= eff;
+        const bool keep_elec = rand01() <= eff;
 
         // Keep electron if pTCone30/pT < 0.13 and eTCone30/pT < 0.2 and reconstructed
         if (keep_elec && pTinCone/e.pT() <= 0.13 && eTinCone/e.pT() < 0.2)
@@ -179,7 +176,7 @@ namespace Rivet {
 
         // Get fiducial lepton efficiency simulate reco efficiency
         const double eff = (_use_fiducial_lepton_efficiency) ? apply_reco_eff(tau_id, tau_vis) : 1.0;
-        const bool keep_tau = rand()/static_cast<double>(RAND_MAX) <= eff;
+        const bool keep_tau = rand01() <= eff;
 
         // Keep tau if nprong = 1, it decays hadronically, and it's reconstructed by the detector
         if ( !lep_decaying_tau && nprong == 1 && keep_tau) tau_candidates.push_back(tau_vis);
@@ -187,11 +184,7 @@ namespace Rivet {
 
 
       // Jets (all anti-kt R=0.4 jets with pT > 25 GeV and eta < 4.9)
-      Jets jet_candidates;
-      for (const Jet& jet : apply<FastJets>(event, "AntiKtJets04").jetsByPt(25*GeV)) {
-        if (jet.abseta() < 4.9) jet_candidates.push_back(jet);
-      }
-
+      Jets jet_candidates = apply<FastJets>(event, "AntiKtJets04").jetsByPt(Cuts::pT > 25*GeV && Cuts::abseta < 4.9);
 
       // ETmiss
       Particles vfs_particles = apply<VisibleFinalState>(event, "VFS").particles();
@@ -324,7 +317,7 @@ namespace Rivet {
 
 
       // Jet cleaning
-      if (rand()/static_cast<double>(RAND_MAX) <= 0.42) {
+      if (rand01() <= 0.42) {
         for (const Jet& jet : recon_jets) {
           const double eta = jet.rapidity();
           const double phi = jet.azimuthalAngle(MINUSPI_PLUSPI);
@@ -348,8 +341,8 @@ namespace Rivet {
       if (recon_mu.size() + recon_e.size() + recon_tau.size() < 3 || recon_leptons.size() < 2) vetoEvent;
 
       // Sort leptons by decreasing pT
-      sortByPt(recon_leptons);
-      sortByPt(recon_tau);
+      isortByPt(recon_leptons);
+      isortByPt(recon_tau);
 
       // Calculate HTlep, fill lepton pT histograms & store chosen combination of 3 leptons
       double HTlep = 0.;
@@ -503,7 +496,7 @@ namespace Rivet {
 
 
     /// Helper functions
-    //@{
+    /// @{
 
     /// Function giving a list of all signal regions
     vector<string> getSignalRegions()  {
@@ -1027,18 +1020,18 @@ namespace Rivet {
       return onZ;
     }
 
-    //@}
+    /// @}
 
 
   private:
 
     /// Histograms
-    //@{
+    /// @{
     Histo1DPtr _h_HTlep_all, _h_HTjets_all, _h_MET_all, _h_Meff_all;
     Histo1DPtr _h_pt_1_3l, _h_pt_2_3l, _h_pt_3_3l, _h_pt_1_2ltau, _h_pt_2_2ltau, _h_pt_3_2ltau;
     Histo1DPtr _h_e_n, _h_mu_n, _h_tau_n;
     Histo1DPtr _h_excluded;
-    //@}
+    /// @}
 
     /// Fiducial efficiencies to model the effects of the ATLAS detector
     bool _use_fiducial_lepton_efficiency;
@@ -1051,7 +1044,6 @@ namespace Rivet {
   };
 
 
-
   RIVET_DECLARE_PLUGIN(ATLAS_2012_I1204447);
 
 }
