@@ -93,11 +93,6 @@ namespace Rivet {
       const vector<double> br = {0.05961,0.00793,0.05961,0.00793,0.0248,0.0193,0.0218};
       for (unsigned int ix=0; ix<7; ++ix) {
         scale(_h_Onium[ix], factor*br[ix]);
-        for(auto & hist : _h_Onium[ix]->bins()) {
-          for(auto & b : hist->bins()) {
-            b.scaleW(1./_axes[ix].width(b.index()));
-          }
-        }
         divByGroupWidth(_h_Onium[ix]);
       }
     }
