@@ -32,12 +32,12 @@ namespace Rivet {
       double FQC = 1.-FGC;
       double FQF = 1.-FGF;
 
-      for (size_t i=0; i<hGluon->numBins(); i++) {
-        double binCenter = hGluon->bin(i).midpoint();
+      for (size_t i=1; i<hGluon->numBins()+1; i++) {
+        double binCenter = hGluon->bin(i).xMid();
         double gVal = 0., qVal = 0.;
         if ((FQF -  FQC) != 0.) {
-          gVal = (FQF * hCentral->bin(ptbin*(nBins) + i).height() - FQC * hForward->bin(ptbin*(nBins) + i).height()) / (FQF - FQC);
-          qVal = (FGF * hCentral->bin(ptbin*(nBins) + i).height() - FGC * hForward->bin(ptbin*(nBins) + i).height()) / (FQC - FQF);
+          gVal = (FQF * hCentral->bin(ptbin*(nBins) + i).sumW() - FQC * hForward->bin(ptbin*(nBins) + i).sumW()) / (FQF - FQC);
+          qVal = (FGF * hCentral->bin(ptbin*(nBins) + i).sumW() - FGC * hForward->bin(ptbin*(nBins) + i).sumW()) / (FQC - FQF);
         }
         hGluon->fill(binCenter, gVal);
         hQuark->fill(binCenter, qVal);
@@ -90,12 +90,12 @@ namespace Rivet {
 
           if (var=="rg" || var=="trg") {
             binWidth = rgBins[j+1]- rgBins[j];
-            if (j==nBins-1) ptBinnedHist->bin( k*nBins+j ).scaleW(2.);
-            //normalization += ptBinnedHist->bin(k*nBins+j).height()*binWidth;
-            normalization += ptBinnedHist->bin(k*(nBins) + j).height()*binWidth;
+            if (j==nBins-1) ptBinnedHist->bin( k*nBins+j+1 ).scaleW(2.);
+            //normalization += ptBinnedHist->bin(k*nBins+j).sumW()*binWidth;
+            normalization += ptBinnedHist->bin(k*(nBins) + j+1).sumW()*binWidth;
           }
           else{
-            normalization += ptBinnedHist->bin(k*(nBins) + j).height()*binWidth;
+            normalization += ptBinnedHist->bin(k*(nBins) + j+1).sumW()*binWidth;
           }
         }
 
@@ -103,10 +103,10 @@ namespace Rivet {
 
         for (unsigned int j=0; j<nBins; j++) {
           if (var=="rg" || var=="trg") {
-            ptBinnedHist->bin(k*(nBins) + j ).scaleW(1. / (normalization) );
+            ptBinnedHist->bin(k*(nBins) + j+1 ).scaleW(1. / (normalization) );
           }
           else{
-            ptBinnedHist->bin(k*(nBins) + j ).scaleW(1. / (normalization));
+            ptBinnedHist->bin(k*(nBins) + j+1 ).scaleW(1. / (normalization));
           }
 
         }
@@ -117,18 +117,12 @@ namespace Rivet {
 
     void histNorm(Rivet::Histo1DPtr hist, std::string var) {
       if (var=="m" || var=="tm") {
-        double norm = 0.;
-        for (size_t i = normBin1; i < normBin2; i++) { //only normalize in the resummation region.
-          norm+=hist->bin(i).area();
-        }
+        const double norm = hist->integralRange(normBin1+1, normBin2);
         if (norm > 0.) {
-          hist->scaleW(1.0/(norm));
+          hist->scaleW(1.0/norm);
         }
       }
-      else if ( var=="zg" || var=="tzg") {
-        normalize(hist);
-      }
-      else{
+      else {
         normalize(hist);
       }
     }
@@ -232,7 +226,7 @@ namespace Rivet {
       // All final state particles
       const FinalState fs(Cuts::abseta < 5.0);
 
-      FastJets jets(fs, FastJets::ANTIKT, 0.8, JetAlg::Muons::NONE, JetAlg::Invisibles::NONE);
+      FastJets jets(fs, JetAlg::ANTIKT, 0.8, JetMuons::NONE, JetInvisibles::NONE);
       declare(jets, "jets");
 
       ChargedFinalState tracks(Cuts::pT > 0.5*GeV && Cuts::abseta < 2.5);
@@ -433,7 +427,7 @@ namespace Rivet {
 
     void analyze(const Event& event) {
 
-      const Jets& myJets = apply<FastJets>(event, "jets").jetsByPt(200*GeV);
+      const Jets& myJets = apply<FastJets>(event, "jets").jetsByPt(Cuts::pT > 200*GeV);
       const Particles& tracks = apply<ChargedFinalState>(event, "tracks").particlesByPt();
 
       if (myJets.size() < 2)  vetoEvent;
