@@ -148,10 +148,10 @@ namespace Rivet {
      const Cut jetscut25 = (Cuts::pT > 25*GeV && Cuts::abseta < 2.5) || (Cuts::pT > 50*GeV && Cuts::absetaIn(2.5, 4.4));
      Jets jetsMix = apply<FastJets>(event, "jets").jetsByPt(jetscut);
      Jets jetsMix25 = apply<FastJets>(event, "jets").jetsByPt(jetscut25);
-     iselectIfAnyDeltaRLess(jetsMix, photons, 0.4);
-     iselectIfAnyDeltaRLess(jetsMix, electrons, 0.2);
-     iselectIfAnyDeltaRLess(jetsMix25, photons, 0.4);
-     iselectIfAnyDeltaRLess(jetsMix25, electrons, 0.2);
+     idiscardIfAnyDeltaRLess(jetsMix, photons, 0.4);
+     idiscardIfAnyDeltaRLess(jetsMix, electrons, 0.2);
+     idiscardIfAnyDeltaRLess(jetsMix25, photons, 0.4);
+     idiscardIfAnyDeltaRLess(jetsMix25, electrons, 0.2);
 
      // Jet multiplicity
      size_t njets = jetsMix.size();
