@@ -113,24 +113,27 @@ namespace Rivet {
         BinnedEstimatePtr<string> tmp[3];
         for (unsigned int ix=0;ix<3;++ix) book(tmp[ix],3*il+9+ix,1,1);
         for (unsigned int iy=0;iy<_p[il][0]->numBins();++iy) {
+          const double N = _p[il][0]->bin(iy+1).effNumEntries();
           double q2  = _p[il][0]->bin(iy+1).mean(2), q4  = _p[il][1]->bin(iy+1).mean(2),
                  q6  = _p[il][2]->bin(iy+1).mean(2), q8  = _p[il][3]->bin(iy+1).mean(2),
                  q10 = _p[il][4]->bin(iy+1).mean(2), q12 = _p[il][5]->bin(iy+1).mean(2),
                  q14 = _p[il][6]->bin(iy+1).mean(2), q16 = _p[il][7]->bin(iy+1).mean(2);
           // q4 case
-          double N = _p[il][0]->bin(iy+1).effNumEntries();
+          if (N <= 9) continue; // q8 needs 8 events + Bessel correction
           double value = q4 - sqr(q2);
           double error = (-sqr(q4) + 4*sqr(q2)*(-sqr(q2) + 2*q4) - 4*q2*q6 + q8)/N;
           tmp[0]->bin(iy+1).set(value,sqrt(error));
           // q6 case
+          if (N <= 13) continue; // q12 needs 12 events + Bessel correction
           value = q6 + q2*(2*sqr(q2) - 3*q4);
-          error = (q12 - sqr(q6) - 6*q2*(q10 - 5*q4*q6) + 3*q4*(3*sqr(q4) - 2*q8) + 
+          error = (q12 - sqr(q6) - 6*q2*(q10 - 5*q4*q6) + 3*q4*(3*sqr(q4) - 2*q8) +
                    sqr(q2)*(-72*sqr(q4) + 36*sqr(q2)*(-sqr(q2) + 3*q4) - 48*q2*q6 + 21*q8))/N;
           tmp[1]->bin(iy+1).set(value,sqrt(error));
           // q8 case
+          if (N <= 17) continue; // q16 needs 16 events + Bessel correction
           value = q8 + q2*(-3*q2*sqr(q2) + 6*q2*q4 - 4*q6);
-          error = (q16 - 8*q6*(q10 - 2*q4*q6) - sqr(q8) - 8*q2*(q14 - 3*q4*(q10 - 4*q4*q6) - 6*q6*q8) + 
-                   4*sqr(q2)*(7*q12 - 28*sqr(q6) + 6*q2*(-3*q10 + 22*q4*q6) + 3*q4*(12*sqr(q4) - 11*q8) + 
+          error = (q16 - 8*q6*(q10 - 2*q4*q6) - sqr(q8) - 8*q2*(q14 - 3*q4*(q10 - 4*q4*q6) - 6*q6*q8) +
+                   4*sqr(q2)*(7*q12 - 28*sqr(q6) + 6*q2*(-3*q10 + 22*q4*q6) + 3*q4*(12*sqr(q4) - 11*q8) +
                                   3*sqr(q2)*(-12*sqr(q2)*(sqr(q2) - 4*q4) - 51*sqr(q4) - 28*q2*q6 + 13*q8)))/N;
           tmp[2]->bin(iy+1).set(value,sqrt(error));
         }
