@@ -15,7 +15,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -23,19 +23,27 @@ namespace Rivet {
       declare(FinalState(), "FS");
       declare(UnstableParticles(), "UFS");
       // Book histograms
-      book(_nD1D, "/TMP/nD1D");
-      book(_nPsi, "/TMP/nPsi");
+      book(_nD1D, 1, 1,  1);
+      book(_nPsi, 1, 1,  2);
+      for (const string& en : _nD1D.binning().edges<0>()) {
+        const double end = std::stod(en)*MeV;
+        if (isCompatibleWithSqrtS(end)) {
+          _ecms = en;
+          break;
+        }
+      }
+      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
 
     }
 
     void findChildren(const Particle & p,map<long,int> & nRes, int &ncount) {
       for(const Particle &child : p.children()) {
-	if(child.children().empty()) {
-	  nRes[child.pid()]-=1;
-	  --ncount;
-	}
-	else
-	  findChildren(child,nRes,ncount);
+        if(child.children().empty()) {
+          nRes[child.pid()]-=1;
+          --ncount;
+        }
+        else
+          findChildren(child,nRes,ncount);
       }
     }
 
@@ -51,21 +59,21 @@ namespace Rivet {
       }
       const FinalState& ufs = apply<FinalState>(event, "UFS");
       bool matched=false;
-      for (const Particle& p1 : ufs.particles(Cuts::abspid==411)) {
+      for(const Particle& p1 : ufs.particles(Cuts::abspid==411)) {
         int sign = p1.pid()/411;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p1,nRes,ncount);
         matched=false;
-        for (const Particle& p2 : ufs.particles(Cuts::pid==-sign*411)) {
+        for(const Particle& p2 : ufs.particles(Cuts::pid==-sign*411)) {
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if (ncount2!=1) continue;
+          if(ncount2!=2) continue;
           matched=true;
-          for (auto const & val : nRes2) {
-            if (abs(val.first)==211) {
-              if (val.second!=1) {
+          for(auto const & val : nRes2) {
+            if(abs(val.first)==211) {
+              if(val.second!=1) {
                 matched = false;
                 break;
               }
@@ -80,10 +88,10 @@ namespace Rivet {
         if(matched)
           break;
       }
-      if (!matched) vetoEvent;
+      if(!matched) vetoEvent;
       // psi(3770) pi+pi-
-      for (const Particle& p1 : ufs.particles(Cuts::abspid==30443)) {
-       	if (p1.children().empty()) continue;
+      for(const Particle& p1 : ufs.particles(Cuts::abspid==30443)) {
+        if(p1.children().empty()) continue;
         map<long,int> nRes = nCount;
         int ncount = ntotal;
         findChildren(p1,nRes,ncount);
@@ -103,32 +111,26 @@ namespace Rivet {
           }
         }
         if(matched) {
-          _nPsi->fill();
-          break;
+          _nPsi->fill(_ecms);
+          return;
         }
       }
       // D1 D
-      for (const Particle& p1 : ufs.particles(Cuts::abspid==10413)) {
-       	if(p1.children().empty()) continue;
-      	int sign = p1.pid()/10413;
-      	map<long,int> nRes = nCount;
-      	int ncount = ntotal;
-      	findChildren(p1,nRes,ncount);
-      	matched=false;
-        for (const Particle& p2 : ufs.particles(Cuts::pid==-sign*411)) {
+      for(const Particle& p1 : ufs.particles(Cuts::abspid==10413)) {
+        if(p1.children().empty()) continue;
+        int sign = p1.pid()/10413;
+        map<long,int> nRes = nCount;
+        int ncount = ntotal;
+        findChildren(p1,nRes,ncount);
+        matched=false;
+        for(const Particle& p2 : ufs.particles(Cuts::pid==-sign*411)) {
           map<long,int> nRes2 = nRes;
           int ncount2 = ncount;
           findChildren(p2,nRes2,ncount2);
-          if(ncount2!=1) continue;
+          if(ncount2!=0) continue;
           matched=true;
           for(auto const & val : nRes2) {
-            if(abs(val.first)==211) {
-              if(val.second!=1) {
-          matched = false;
-          break;
-              }
-            }
-            else if(val.second!=0) {
+            if(val.second!=0) {
               matched = false;
               break;
             }
@@ -136,8 +138,8 @@ namespace Rivet {
           if(matched) break;
         }
         if(matched) {
-          _nD1D->fill();
-                break;
+          _nD1D->fill(_ecms);
+          return;
         }
       }
     }
@@ -145,48 +147,21 @@ namespace Rivet {
     /// Normalise histograms etc., after the run
     void finalize() {
       double fact = crossSection()/ sumOfWeights()/picobarn;
-      for (unsigned int iy = 9; iy < 11; ++iy) {
-        double sigma=0.,error=0.;
-        if(iy==9) {
-          sigma = _nD1D->val()*fact;
-          error = _nD1D->err()*fact;
-        }
-        else if(iy==10) {
-          sigma = _nPsi->val()*fact;
-          error = _nPsi->err()*fact;
-        }
-        Scatter2D temphisto(refData(1, 1, iy));
-        Scatter2DPtr mult;
-        book(mult,1,1,iy);
-        for (size_t b = 0; b < temphisto.numPoints(); b++) {
-          const double x  = temphisto.point(b).x();
-          pair<double,double> ex = temphisto.point(b).xErrs();
-          pair<double,double> ex2 = ex;
-          if(ex2.first ==0.) ex2. first=0.0001;
-          if(ex2.second==0.) ex2.second=0.0001;
-          if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-            mult->addPoint(x, sigma, ex, make_pair(error,error));
-          }
-          else {
-            mult->addPoint(x, 0., ex, make_pair(0.,.0));
-          }
-        }
-      }
-
+      scale(_nD1D,fact);
+      scale(_nPsi,fact);
     }
 
-    //@}
+    /// @}
 
     /// @name Histograms
-    //@{
-    CounterPtr _nD1D, _nPsi;
-    //@}
+    /// @{
+    BinnedHistoPtr<string> _nD1D, _nPsi;
+    string _ecms;
+    /// @}
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(BESIII_2019_I1756876);
 
-
 }
