@@ -21,7 +21,16 @@ namespace Rivet {
 
       // Initialise and register projections
       declare(UnstableParticles(), "UFS");
-      book(_c_psi   , "/TMP/sigma_psi");
+      book(_c_psi   , 1, 1, 1);
+
+      for (const string& en : _c_psi.binning().edges<0>()) {
+        const double end = std::stod(en)*GeV;
+        if (isCompatibleWithSqrtS(end)) {
+          _ecms = en;
+          break;
+        }
+      }
+      if (_ecms.empty()) MSG_ERROR("Beam energy incompatible with analysis.");
     }
 
 
@@ -29,31 +38,13 @@ namespace Rivet {
     void analyze(const Event& event) {
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
       unsigned int count = ufs.particles(Cuts::pid==443).size();
-      _c_psi->fill(count);
+      _c_psi->fill(_ecms,count);
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double fact = crossSection()/nanobarn/sumOfWeights();
-      double sigma = _c_psi->val()*fact;
-      double error = _c_psi->err()*fact;
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr mult;
-      book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-	  mult   ->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult   ->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      scale(_c_psi, crossSection()/nanobarn/sumOfWeights());
     }
 
     ///@}
@@ -61,7 +52,8 @@ namespace Rivet {
 
     /// @name Histograms
     ///@{
-    CounterPtr _c_psi;
+    BinnedHistoPtr<string> _c_psi;
+    string _ecms;
     ///@}
 
 
