@@ -29,7 +29,7 @@ namespace Rivet {
       // Book histograms
       book(_h_T2, "TMP/T2",20,-1.,1.);
       book(_h_T3, "TMP/T3",20,-1.,1.);
-      book(_h_cThetaL,"cThetaL",20,-1.,1.);
+      book(_h_cThetaL,"TMP/cThetaL",20,-1.,1.);
       book(_wsum,"TMP/wsum");
 
       vector<string> energies({"3.68", "3.683", "3.684", "3.685", "3.687", "3.691", "3.71"});
