@@ -16,7 +16,7 @@ namespace Rivet {
     public:
 
       /// @name Standard constructors and destructors.
-      //@{
+      /// @{
 
       /// The default constructor. May specify the minimum and maximum
       /// pseudorapidity \f$ \eta \f$ and the min \f$ p_T \f$ (in GeV).
@@ -42,9 +42,9 @@ namespace Rivet {
       virtual const DecayMode& mode2() const {return _mode2;}
 
       /// Clone on the heap.
-      DEFAULT_RIVET_PROJ_CLONE(PseudoTop);
+      RIVET_DEFAULT_PROJ_CLONE(PseudoTop);
 
-      //@}
+      /// @}
 
       /// Import to avoid warnings about overload-hiding
       using Projection::operator =;
@@ -146,39 +146,37 @@ namespace Rivet {
       const FourMomentum ttP4 = t1P4 + t2P4;
       const FourMomentum t1P4AtCM = LorentzTransform::mkFrameTransformFromBeta(ttP4.betaVec()).transform(t1P4);
 
-      const double weight = 1.0;
-
       if ( ttbar.mode() == PseudoTop::CH_SEMILEPTON ) {
         const Particle lCand1 = ttbar.wDecays1()[0]; // w1 dau0 is the lepton in the PseudoTop
         if (lCand1.pT() < 33*GeV || lCand1.abseta() > 2.1) vetoEvent;
-        _hSL_topPt->fill(t1P4.pT(), weight);
-        _hSL_topPt->fill(t2P4.pT(), weight);
-        _hSL_topPtTtbarSys->fill(t1P4AtCM.pT(), weight);
-        _hSL_topY->fill(t1P4.rapidity(), weight);
-        _hSL_topY->fill(t2P4.rapidity(), weight);
-        _hSL_ttbarDelPhi->fill(dPhi, weight);
-        _hSL_topPtLead->fill(pt1, weight);
-        _hSL_topPtSubLead->fill(pt2, weight);
-        _hSL_ttbarPt->fill(ttP4.pT(), weight);
-        _hSL_ttbarY->fill(ttP4.rapidity(), weight);
-        _hSL_ttbarMass->fill(ttP4.mass(), weight);
+        _hSL_topPt->fill(t1P4.pT());
+        _hSL_topPt->fill(t2P4.pT());
+        _hSL_topPtTtbarSys->fill(t1P4AtCM.pT());
+        _hSL_topY->fill(t1P4.rapidity());
+        _hSL_topY->fill(t2P4.rapidity());
+        _hSL_ttbarDelPhi->fill(dPhi);
+        _hSL_topPtLead->fill(pt1);
+        _hSL_topPtSubLead->fill(pt2);
+        _hSL_ttbarPt->fill(ttP4.pT());
+        _hSL_ttbarY->fill(ttP4.rapidity());
+        _hSL_ttbarMass->fill(ttP4.mass());
       }
       else if ( ttbar.mode() == PseudoTop::CH_FULLLEPTON ) {
         const Particle lCand1 = ttbar.wDecays1()[0]; // dau0 are the lepton in the PseudoTop
         const Particle lCand2 = ttbar.wDecays2()[0]; // dau0 are the lepton in the PseudoTop
         if (lCand1.pT() < 20*GeV || lCand1.abseta() > 2.4) vetoEvent;
         if (lCand2.pT() < 20*GeV || lCand2.abseta() > 2.4) vetoEvent;
-        _hDL_topPt->fill(t1P4.pT(), weight);
-        _hDL_topPt->fill(t2P4.pT(), weight);
-        _hDL_topPtTtbarSys->fill(t1P4AtCM.pT(), weight);
-        _hDL_topY->fill(t1P4.rapidity(), weight);
-        _hDL_topY->fill(t2P4.rapidity(), weight);
-        _hDL_ttbarDelPhi->fill(dPhi, weight);
-        _hDL_topPtLead->fill(pt1, weight);
-        _hDL_topPtSubLead->fill(pt2, weight);
-        _hDL_ttbarPt->fill(ttP4.pT(), weight);
-        _hDL_ttbarY->fill(ttP4.rapidity(), weight);
-        _hDL_ttbarMass->fill(ttP4.mass(), weight);
+        _hDL_topPt->fill(t1P4.pT());
+        _hDL_topPt->fill(t2P4.pT());
+        _hDL_topPtTtbarSys->fill(t1P4AtCM.pT());
+        _hDL_topY->fill(t1P4.rapidity());
+        _hDL_topY->fill(t2P4.rapidity());
+        _hDL_ttbarDelPhi->fill(dPhi);
+        _hDL_topPtLead->fill(pt1);
+        _hDL_topPtSubLead->fill(pt2);
+        _hDL_ttbarPt->fill(ttP4.pT());
+        _hDL_ttbarY->fill(ttP4.rapidity());
+        _hDL_ttbarMass->fill(ttP4.mass());
       }
 
     }
@@ -274,12 +272,9 @@ namespace Rivet {
     }
 
 
-    void applyCorrection(Histo1DPtr h, const double* cf) {
-      vector<YODA::HistoBin1D>& bins = h->bins();
-      for (size_t i=0, n=bins.size(); i<n; ++i ) {
-        const double s = cf[i];
-        YODA::HistoBin1D& bin = bins[i];
-        bin.scaleW(s);
+    void applyCorrection(Histo1DPtr& h, const double* cf) {
+      for (auto& bin : h->bins()) {
+        bin.scaleW( cf[bin.index()-1] );
       }
     }
 
@@ -438,17 +433,16 @@ namespace Rivet {
       }
 
       // Start object building from trivial thing - prompt neutrinos
-      sortByPt(neutrinos);
+      isortByPt(neutrinos);
 
       // Proceed to lepton dressing
-      FastJets fjLep(FinalState(), FastJets::ANTIKT, _lepR);
+      FastJets fjLep(FinalState(), JetAlg::ANTIKT, _lepR);
       fjLep.calc(pForLep);
 
       Jets leptons;
       vector<int> leptonsId;
       set<int> dressedIdxs;
-      for (const Jet& lep : fjLep.jetsByPt(_lepMinPt)) {
-        if (lep.abseta() > _lepMaxEta) continue;
+      for (const Jet& lep : fjLep.jetsByPt(Cuts::pT > _lepMinPt && Cuts::abseta < _lepMaxEta)) {
         double leadingPt = -1;
         int leptonId = 0;
         for (const Particle& p : lep.particles()) {
@@ -474,11 +468,10 @@ namespace Rivet {
       }
 
       // Then do the jet clustering
-      FastJets fjJet(FinalState(), FastJets::ANTIKT, _jetR);
+      FastJets fjJet(FinalState(), JetAlg::ANTIKT, _jetR);
       //fjJet.useInvisibles(); // NOTE: CMS proposal to remove neutrinos (AB: wouldn't work anyway, since they were excluded from clustering inputs)
       fjJet.calc(pForJet);
-      for (const Jet& jet : fjJet.jetsByPt(_jetMinPt)) {
-        if (jet.abseta() > _jetMaxEta) continue;
+      for (const Jet& jet : fjJet.jetsByPt(Cuts::pT > _jetMinPt && Cuts::abseta < _jetMaxEta)) {
         _jets.push_back(jet);
         bool isBJet = false;
         for (const Particle& rp : jet.particles()) {
