@@ -3,7 +3,7 @@
 #include "Rivet/Projections/FinalState.hh"
 #include "Rivet/Projections/FastJets.hh"
 #include "Rivet/Projections/ChargedLeptons.hh"
-#include "Rivet/Projections/DressedLeptons.hh"
+#include "Rivet/Projections/LeptonFinder.hh"
 #include "Rivet/Projections/MissingMomentum.hh"
 #include "Rivet/Projections/PromptFinalState.hh"
 #include "Rivet/Projections/VetoedFinalState.hh"
@@ -24,7 +24,7 @@ namespace Rivet {
     void init() override {
 
       // final state of all stable particles
-      Cut particle_cut = (Cuts::abseta < 5.0) and (Cuts::pT > 0.*MeV);
+      Cut particle_cut = Cuts::abseta < 5.0;
       FinalState fs(particle_cut);
 
       // select charged leptons
@@ -43,21 +43,14 @@ namespace Rivet {
       prompt_photons.acceptTauDecays(true);
 
       // Dressed leptons from selected prompt charged leptons and photons
-      Cut lepton_cut   = (Cuts::abseta < 2.4) and (Cuts::pT > 26.*GeV);
-      DressedLeptons dressed_leptons(
-        prompt_photons, prompt_leptons, 0.1,
-        lepton_cut, true
-      );
-      declare(dressed_leptons, "DressedLeptons");
+      Cut lepton_cut = Cuts::abseta < 2.4 and Cuts::pT > 26*GeV;
+      LeptonFinder dressed_leptons(prompt_leptons, prompt_photons, 0.1, lepton_cut);
+      declare(dressed_leptons, "LeptonFinder");
 
       // Jets
       VetoedFinalState fsForJets(fs);
       fsForJets.addVetoOnThisFinalState(dressed_leptons);
-      declare(
-        // excludes all neutrinos by default
-        FastJets(fsForJets, FastJets::ANTIKT, 0.4),
-        "Jets"
-      );
+      declare(FastJets(fsForJets, JetAlg::ANTIKT, 0.4), "Jets"); //< excludes all neutrinos by default
 
       // Neutrinos
       IdentifiedFinalState neutrinos(fs);
@@ -128,7 +121,7 @@ namespace Rivet {
 
     /// @brief Perform the per-event analysis
     void analyze(const Event& event) override {
-      vector<Particle> topQuarks = applyProjection<PartonicTops>(
+      vector<Particle> topQuarks = apply<PartonicTops>(
         event,
         "TopQuarks"
       ).tops();
@@ -139,10 +132,7 @@ namespace Rivet {
         return;
       }
 
-      vector<DressedLepton> dressedLeptons = applyProjection<DressedLeptons>(
-        event,
-        "DressedLeptons"
-      ).dressedLeptons();
+      DressedLeptons dressedLeptons = apply<LeptonFinder>(event, "LeptonFinder").dressedLeptons();
 
       // only analyze events with one dressed lepton (muon or electron)
       if (dressedLeptons.size()!=1) {
@@ -176,7 +166,7 @@ namespace Rivet {
 
       /* find unknown pz component of missing transverse momentum by imposing
          a W boson mass constraint */
-      std::pair<FourMomentum,FourMomentum> nuMomentum = NuMomentum(
+      pair<FourMomentum,FourMomentum> nuMomentum = NuMomentum(
         dressedLeptons[0].px(), dressedLeptons[0].py(), dressedLeptons[0].pz(),
         dressedLeptons[0].E(), met.px(), met.py()
       );
@@ -282,8 +272,6 @@ namespace Rivet {
       }
     }
 
-    //@}
-
 
   private:
 
@@ -294,35 +282,35 @@ namespace Rivet {
     // Top quark pt histograms and ratio
     Histo1DPtr _hist_abs_top_pt;
     Histo1DPtr _hist_norm_top_pt;
-    Scatter2DPtr _hist_ratio_top_pt;
+    Estimate1DPtr _hist_ratio_top_pt;
     Histo1DPtr _hist_t_top_pt;
     Histo1DPtr _hist_tbar_top_pt;
 
     // Top quark rapidity histograms and ratio
     Histo1DPtr _hist_abs_top_y;
     Histo1DPtr _hist_norm_top_y;
-    Scatter2DPtr _hist_ratio_top_y;
+    Estimate1DPtr _hist_ratio_top_y;
     Histo1DPtr _hist_t_top_y;
     Histo1DPtr _hist_tbar_top_y;
 
     // Charged lepton pt histograms and ratio
     Histo1DPtr _hist_abs_lepton_pt;
     Histo1DPtr _hist_norm_lepton_pt;
-    Scatter2DPtr _hist_ratio_lepton_pt;
+    Estimate1DPtr _hist_ratio_lepton_pt;
     Histo1DPtr _hist_t_lepton_pt;
     Histo1DPtr _hist_tbar_lepton_pt;
 
     // Charged lepton rapidity histograms and ratio
     Histo1DPtr _hist_abs_lepton_y;
     Histo1DPtr _hist_norm_lepton_y;
-    Scatter2DPtr _hist_ratio_lepton_y;
+    Estimate1DPtr _hist_ratio_lepton_y;
     Histo1DPtr _hist_t_lepton_y;
     Histo1DPtr _hist_tbar_lepton_y;
 
     // W boson pt histograms and ratio
     Histo1DPtr _hist_abs_w_pt;
     Histo1DPtr _hist_norm_w_pt;
-    Scatter2DPtr _hist_ratio_w_pt;
+    Estimate1DPtr _hist_ratio_w_pt;
     Histo1DPtr _hist_t_w_pt;
     Histo1DPtr _hist_tbar_w_pt;
 
@@ -356,7 +344,7 @@ namespace Rivet {
     /** @brief helper function to solve for the unknown neutrino pz momentum
      *  using a W boson mass constraint
      */
-    std::pair<FourMomentum,FourMomentum> NuMomentum(
+    pair<FourMomentum,FourMomentum> NuMomentum(
       double pxlep, double pylep, double pzlep,
       double elep, double metpx, double metpy
     ) {
@@ -367,10 +355,10 @@ namespace Rivet {
       double misET2 = (metpx * metpx + metpy * metpy);
       double mu = (WMASS * WMASS) / 2 + metpx * pxlep + metpy * pylep;
       double a  = (mu * pzlep) / (elep * elep - pzlep * pzlep);
-      double a2 = std::pow(a, 2);
+      double a2 = pow(a, 2);
 
-      double b  = (std::pow(elep, 2.) * (misET2) - std::pow(mu, 2.))
-                  / (std::pow(elep, 2) - std::pow(pzlep, 2));
+      double b  = (pow(elep, 2.) * (misET2) - pow(mu, 2.))
+                  / (pow(elep, 2) - pow(pzlep, 2));
 
       double pz1(0), pz2(0), pznu(0), pznu2(0);
 
@@ -467,7 +455,7 @@ namespace Rivet {
                                  + (pyZeroValue - metpy) * (pyZeroValue - metpy);
 
         if (deltaMin == 14000 * 14000) {
-          return std::make_pair(result, result2);
+          return make_pair(result, result2);
         }
 
         if (delta2ZeroValue < deltaMin) {
@@ -485,28 +473,28 @@ namespace Rivet {
         double Enu = sqrt(minPx * minPx + minPy * minPy + pznu * pznu);
         result.setXYZE(minPx, minPy, pznu , Enu);
       }
-      return std::make_pair(result, result2);
+      return make_pair(result, result2);
     }
 
 
     /// @brief helper function find root of the cubic equation a*x^3 + b*x^2 + c*x + d = 0
-    std::vector<double> EquationSolve(
+    vector<double> EquationSolve(
       double a, double b,
       double c, double d
     ) {
-      std::vector<double> result;
+      vector<double> result;
 
-      std::complex<double> x1;
-      std::complex<double> x2;
-      std::complex<double> x3;
+      complex<double> x1;
+      complex<double> x2;
+      complex<double> x3;
 
       double q = (3 * a * c - b * b) / (9 * a * a);
       double r = (9 * a * b * c - 27 * a * a * d - 2 * b * b * b
                  ) / (54 * a * a * a);
       double Delta = q * q * q + r * r;
 
-      std::complex<double> s;
-      std::complex<double> t;
+      complex<double> s;
+      complex<double> t;
 
       double rho = 0;
       double theta = 0;
@@ -516,27 +504,27 @@ namespace Rivet {
 
         theta = acos(r / rho);
 
-        s = std::polar<double>(sqrt(-q), theta / 3.0);
-        t = std::polar<double>(sqrt(-q), -theta / 3.0);
+        s = polar<double>(sqrt(-q), theta / 3.0);
+        t = polar<double>(sqrt(-q), -theta / 3.0);
       }
 
       if (Delta > 0) {
-        s = std::complex<double>(cbrt(r + sqrt(Delta)), 0);
-        t = std::complex<double>(cbrt(r - sqrt(Delta)), 0);
+        s = complex<double>(cbrt(r + sqrt(Delta)), 0);
+        t = complex<double>(cbrt(r - sqrt(Delta)), 0);
       }
 
-      std::complex<double> i(0, 1.0);
+      complex<double> i(0, 1.0);
 
 
-      x1 = s + t + std::complex<double>(-b / (3.0 * a), 0);
+      x1 = s + t + complex<double>(-b / (3.0 * a), 0);
 
-      x2 = (s + t) * std::complex<double>(-0.5, 0)
-           - std::complex<double>(b / (3.0 * a), 0)
-           + (s - t) * i * std::complex<double>(sqrt(3) / 2.0, 0);
+      x2 = (s + t) * complex<double>(-0.5, 0)
+           - complex<double>(b / (3.0 * a), 0)
+           + (s - t) * i * complex<double>(sqrt(3) / 2.0, 0);
 
-      x3 = (s + t) * std::complex<double>(-0.5, 0)
-           - std::complex<double>(b / (3.0 * a), 0)
-           - (s - t) * i * std::complex<double>(sqrt(3) / 2.0, 0);
+      x3 = (s + t) * complex<double>(-0.5, 0)
+           - complex<double>(b / (3.0 * a), 0)
+           - (s - t) * i * complex<double>(sqrt(3) / 2.0, 0);
 
       if (fabs(x1.imag()) < 0.0001) result.push_back(x1.real());
       if (fabs(x2.imag()) < 0.0001) result.push_back(x2.real());
