@@ -51,20 +51,18 @@ namespace Rivet {
 
     /// Recursively walk the decay tree to find the charged decay products of @a p
     void findDecayProducts(Particle mother, Particles& charged) {
-      for(const Particle & p: mother.children()) {
+      for (const Particle & p: mother.children()) {
         const int id = p.pid();
-	if(!p.children().empty())
-	  findDecayProducts(p, charged);
-	else if(PID::isCharged(id))
-	  charged.push_back(p);
+        if (!p.children().empty())   findDecayProducts(p, charged);
+        else if(PID::isCharged(id))  charged.push_back(p);
       }
     }
 
     // defn of thrust in paper used just the direction
-    double thrustPrime(const LorentzTransform & boost, const Particles & particles) {
-      vector<Vector3> vecs;
-      for(const Particle & p : particles) {
-	vecs.push_back(boost.transform(p.momentum()).p3().unit());
+    double thrustPrime(const LorentzTransform& boost, const Particles& particles) const {
+      vector<Vector3> vecs; vecs.reserve(particles.size());
+      for (const Particle& p : particles) {
+        vecs.push_back(boost.transform(p.mom()).p3());
       }
       Thrust thrust;
       thrust.calc(vecs);
@@ -75,16 +73,16 @@ namespace Rivet {
     void analyze(const Event& event) {
       // Find the Upsilons among the unstables
       const UnstableParticles& ufs = apply<UnstableParticles>(event, "UFS");
-      Particles upsilons = ufs.particles(Cuts::pid==553 or Cuts::pid==100553);
+      const Particles upsilons = ufs.particles(Cuts::pid==553 or Cuts::pid==100553);
       if (upsilons.empty()) {
         MSG_DEBUG("No Upsilons found => continuum event");
         _weightSum_cont->fill();
-	Particles cfs = apply<ChargedFinalState>(event, "FS").particles();
-	_mult->fill(_ecms,cfs.size());
-	if(_hist_T_cont) {
+        const Particles cfs = apply<ChargedFinalState>(event, "FS").particles();
+        _mult->fill(_ecms,cfs.size());
+        if (_hist_T_cont) {
           LorentzTransform boost;
-	  _hist_T_cont->fill(thrustPrime(boost,cfs));
-	}
+          _hist_T_cont->fill(thrustPrime(boost,cfs));
+        }
       }
       // Upsilon(s) found
       else {
@@ -97,17 +95,17 @@ namespace Rivet {
             boost = LorentzTransform::mkFrameTransformFromBeta(ups.momentum().betaVec());
           // Find the decay products we want
           findDecayProducts(ups, charged);
-	  if(parentId==553) {
-	    _weightSum_Ups1->fill();
-	    _mult->fill("9.4624"s,charged.size());
-	    _hist_T_Ups1->fill(thrustPrime(boost,charged));
-	  }
-	  else {
-	    _weightSum_Ups2->fill();
-	    _mult->fill("10.0148"s,charged.size());
-	    _hist_T_Ups2->fill(thrustPrime(boost,charged));
-	  }
-	}
+          if(parentId==553) {
+            _weightSum_Ups1->fill();
+            _mult->fill("9.4624"s,charged.size());
+            _hist_T_Ups1->fill(thrustPrime(boost,charged));
+          }
+          else {
+            _weightSum_Ups2->fill();
+            _mult->fill("10.0148"s,charged.size());
+            _hist_T_Ups2->fill(thrustPrime(boost,charged));
+          }
+        }
       }
 
     }
