@@ -6,7 +6,7 @@
 namespace Rivet {
 
 
-  /// @brief Add a short analysis description here
+  /// @brief e+ e- > pi+pi-
   class KLOE2_2017_I1634981 : public Analysis {
   public:
 
@@ -15,7 +15,7 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
@@ -23,7 +23,7 @@ namespace Rivet {
       declare(FinalState(), "FS");
 
       // Book histograms
-      book(_npion, "TMP/pion");
+      book(_npion, "TMP/pion", refData(1, 1, 1));
     }
 
     /// Perform the per-event analysis
@@ -33,46 +33,29 @@ namespace Rivet {
       for (const Particle& p : fs.particles()) {
 	if(abs(p.pid())!=PID::PIPLUS) vetoEvent;
       }
-      _npion->fill();
+      _npion->fill(sqr(sqrtS()/GeV));
     }
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double sigma = _npion->val();
-      double error = _npion->err();
-      sigma *= crossSection()/ sumOfWeights() /nanobarn;
-      error *= crossSection()/ sumOfWeights() /nanobarn;
-      Scatter2D temphisto(refData(1, 1, 1));
-      Scatter2DPtr  mult;
+      scale( _npion, crossSection()/ sumOfWeights() /nanobarn);
+      Estimate1DPtr  mult;
       book(mult, 1, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqr(sqrtS()/GeV), x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
+      barchart(_npion,mult);
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    CounterPtr _npion;
-    //@}
+    /// @{
+    Histo1DPtr _npion;
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(KLOE2_2017_I1634981);
 
 
