@@ -15,14 +15,13 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
       // get the hadronic final state
-      const GammaGammaKinematics& gammakin = declare(GammaGammaKinematics(), "Kinematics");
-      const FinalState & fs = declare(GammaGammaFinalState(gammakin), "FS");
-      declare(FastJets(fs, FastJets::KT,1.),"Jets");
+      const FinalState & fs = declare(GammaGammaFinalState(), "FS");
+      declare(FastJets(fs, JetAlg::KT,1.),"Jets");
 
       // Book histograms
       book(_h_y1,1, 1, 1);
@@ -51,19 +50,18 @@ namespace Rivet {
 
     }
 
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
+    /// @{
     Histo1DPtr _h_y1, _h_y2;
-    //@}
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(OPAL_2008_I754316);
 
 
