@@ -71,10 +71,12 @@ namespace Rivet {
       unsigned int iloc = isCompatibleWithSqrtS(8000) ? 10 : 0;
       for(unsigned int ix=0;ix<_h_Ups[0]->numBins();++ix) {
 	Estimate1DPtr tmp;
-	for(unsigned int iups=1;iups<3;++iups) {
-	  book(tmp,6+iups+iloc,1,1+ix);
-	  divide(_h_Ups[iups]->bin(ix+1),_h_Ups[0]->bin(ix+1),tmp);
-	}
+	book(tmp,6+iloc,1,1+ix);
+	divide(_h_Ups[1]->bin(ix+1),_h_Ups[0]->bin(ix+1),tmp);
+	book(tmp,7+iloc,1,1+ix);
+	divide(_h_Ups[2]->bin(ix+1),_h_Ups[0]->bin(ix+1),tmp);
+	book(tmp,8+iloc,1,1+ix);
+	divide(_h_Ups[2]->bin(ix+1),_h_Ups[1]->bin(ix+1),tmp);
       }
       for(unsigned int iups=1;iups<3;++iups) {
 	Estimate1DPtr tmp;
