@@ -14,16 +14,22 @@ namespace Rivet {
 
 
     /// @name Analysis methods
-    //@{
+    /// @{
 
     /// Book histograms and initialise projections before the run
     void init() {
 
       // Initialise and register projections
       declare(ChargedFinalState(), "FS");
-
+      if     ( isCompatibleWithSqrtS(22.0*GeV) ) _sqs = "22.0";
+      else if( isCompatibleWithSqrtS(27.7*GeV) ) _sqs = "27.7";
+      else if( isCompatibleWithSqrtS(30.0*GeV) ) _sqs = "30.0";
+      else if( isCompatibleWithSqrtS(31.6*GeV) ) _sqs = "31.6";
+      else
+        MSG_WARNING("CoM energy of events sqrt(s) = " << sqrtS()/GeV
+                    << " doesn't match any available analysis energy .");
       // Book histograms
-      book(_nHadrons, "TMP/hadrons");
+      book(_mult, 2, 1, 1);
 
     }
 
@@ -31,45 +37,26 @@ namespace Rivet {
     /// Perform the per-event analysis
     void analyze(const Event& event) {
       const ChargedFinalState& fs = apply<ChargedFinalState>(event, "FS");
-      _nHadrons->fill(fs.particles().size());
-
+      _mult->fill(_sqs,fs.particles().size());
     }
 
 
     /// Normalise histograms etc., after the run
     void finalize() {
-      double sigma = _nHadrons->val()/sumOfWeights();
-      double error = _nHadrons->err()/sumOfWeights();
-      Scatter2D temphisto(refData(2, 1, 1));
-      Scatter2DPtr mult;
-      book(mult, 2, 1, 1);
-      for (size_t b = 0; b < temphisto.numPoints(); b++) {
-	const double x  = temphisto.point(b).x();
-	pair<double,double> ex = temphisto.point(b).xErrs();
-	pair<double,double> ex2 = ex;
-	if(ex2.first ==0.) ex2. first=0.0001;
-	if(ex2.second==0.) ex2.second=0.0001;
-	if (inRange(sqrtS()/GeV, x-ex2.first, x+ex2.second)) {
-	  mult->addPoint(x, sigma, ex, make_pair(error,error));
-	}
-	else {
-	  mult->addPoint(x, 0., ex, make_pair(0.,.0));
-	}
-      }
     }
-    //@}
+    /// @}
 
 
     /// @name Histograms
-    //@{
-    CounterPtr _nHadrons;
-    //@}
+    /// @{
+    BinnedProfilePtr<string> _mult;
+    string _sqs;
+    /// @}
 
 
   };
 
 
-  // The hook for the plugin system
   RIVET_DECLARE_PLUGIN(JADE_1979_I142874);
 
 
