@@ -20,9 +20,11 @@ from . import CMS_2011_I878118 # pseudo-2D object should be 1D
 from . import CMS_2015_I1342266 # pseudo-2D object should be 1D
 from . import CMS_2017_I1485195 # slice 2D object into 1D objects
 from . import CMS_2017_I1631985 # add a vector<1D> versions of the 2D AOs
+from . import CMS_2022_I2080534 # remove parton-level bin from histo
 #from . import DELPHI_1993_I356732 # edges apparently completely wrong
 from . import DELPHI_1999_I499183 # swap x and y in table 39
 from . import DELPHI_2000_I524693 # add missing point
+from . import FASER_2024_I2855783 # append data for LHC geometry, nu decay BRs + xsec
 from . import GAMMAGAMMA_1973_I84794 # reorder points
 from . import H1_2002_I588263 # pseudo-3D objects should be 1D
 from . import H1_2016_I1496981 # divide by Q2 bin width
@@ -42,3 +44,4 @@ from . import TASSO_1988_I263859 # remove sum bin and sort out multiplicity
 from . import TASSO_1990_I294755 # remove sum bin
 from . import TPC_1985_I205868 # pseudo-2D object should really be 1D
 from . import ZEUS_1995_I392386 # pseudo-2D object should really be 1D
+from . import ZEUS_2005_I676091 # undo Born-level correction
