@@ -4,8 +4,7 @@ import os, re, logging
 from rivet.util import texpand
 import ast
 
-pat_begin_block = re.compile(r'^(#*\s*)?BEGIN (\w+) ?(\S+)?')
-pat_begin_name_block = re.compile(r'^(#*\s*)?BEGIN (\w+) ?(\S+)? ?(\w+)?')
+pat_begin_block = re.compile(r'^(#*\s*)?BEGIN (\w+) ?(\S+)? ?(\w+)?')
 pat_end_block =   re.compile(r'^(#*\s*)?END (\w+)')
 pat_comment = re.compile(r'^\s*#|^\s*$')
 pat_property = re.compile(r'^(\w+?)\s*=\s*(.*)$')
@@ -50,7 +49,7 @@ def type_conversion(value):
         return value
 
 
-def convert_legacy_plotfile(filename, hpath, section='PLOT'):
+def convert_legacy_plotfile(filename, hpath):
     """Parse a plot file of the old format and return a dict of the same format as the new plot files.
 
     Parameters
@@ -59,8 +58,6 @@ def convert_legacy_plotfile(filename, hpath, section='PLOT'):
         Filename of the .plot file. Should include the .plot extension.
     hpath : str
         The histogram path, usually with the format /AnalysisID/HistogramID.
-    section : str
-        Either PLOT or HISTOGRAM. Mostly just PLOT
     Returns
     -------
     plot_settings : dict
@@ -73,9 +70,6 @@ def convert_legacy_plotfile(filename, hpath, section='PLOT'):
         If section is not PLOT, HISTOGRAM or TEXT.
         This includes the SPECIAL and FUNCTION sections, which could be parsed before.
     """
-    if section not in ('PLOT', 'HISTOGRAM', 'TEXT'):
-        raise ValueError('Expected section to be PLOT, HISTOGRAM or TEXT but got {}.'.format(section))
-
     ## Assemble the list of headers from any matching plotinfo paths and additional style files
     pat_paths = {}
     ret = {}
@@ -83,48 +77,35 @@ def convert_legacy_plotfile(filename, hpath, section='PLOT'):
     if not os.access(filename, os.R_OK):
         return {}
     startreading = False
-    isTextBox = False
+    isAuxBox = False
     with open(filename) as f:
         msec = None
         for line in f:
             m = pat_begin_block.match(line)
             if m:
-                tag, pathpat = m.group(2,3)
+                tag, pathpat, name = m.group(2,3,4)
                 # pathpat could be a regex
                 if pathpat not in pat_paths:
                     try:
                         pat_paths[pathpat] = re.compile(pathpat)
                     except TypeError:
-                        logging.debug("Error reading plot file for {}. Skipping.".format(filename))
+                        logging.debug(f'Error reading plot file for {filename}. Skipping.')
                         return {}
-                if tag == section:
-                    m2 = pat_paths[pathpat].match(hpath)
-                    if m2:
-                        msec = m2
-                        startreading = True
-                        continue
-            m = pat_begin_name_block.match(line)
-            if m:
-                tag, pathpath, name = m.group(2,3,4)
-                if pathpat not in pat_paths:
-                    try:
-                        pat_paths[pathpat] = re.compile(pathpat)
-                    except TypeError:
-                        logging.debug("Error reading plot file for {}. Skipping.".format(filename))
-                        return {}
-                if tag == 'TEXT':
-                    m2 = pat_paths[pathpat].match(hpath)
-                    if m2:
-                        msec = m2
-                        startreading = True
-                        isTextBox = 'text_'+name
-                        ret[isTextBox] = { }
-                        continue
+                if tag not in ('PLOT', 'HISTOGRAM', 'TEXT', 'LINE'):
+                    raise ValueError(f'Expected section to be PLOT, HISTOGRAM, LINE or TEXT but got {tag}.')
+                m2 = pat_paths[pathpat].match(hpath)
+                if m2:
+                    msec = m2
+                    startreading = tag
+                    if tag == 'TEXT' or tag == 'LINE':
+                        isAuxBox = f'{tag.lower()}_{name}'
+                        ret[isAuxBox] = { }
+                    continue
             if not startreading:
                 continue
-            if _is_end_marker(line, section):
+            if _is_end_marker(line, startreading):
                 startreading = False
-                isTextBox = False
+                isAuxBox = False
                 continue
             elif _is_comment(line):
                 continue
@@ -141,8 +122,8 @@ def convert_legacy_plotfile(filename, hpath, section='PLOT'):
                         value = msec.expand(value)
                     except Exception as e: # TODO: bad exception handling
                         value = oldval #< roll back escapes if it goes wrong
-                if isTextBox:
-                    ret[isTextBox][prop] = type_conversion(texpand(value))
+                if isAuxBox:
+                    ret[isAuxBox][prop] = type_conversion(texpand(value))
                 else:
                     ret[prop] = type_conversion(texpand(value)) #< expand TeX shorthands and convert type if necessary
             vm = pat_property_opt.match(line)
