@@ -121,6 +121,8 @@ def _get_histos(filelist, plotoptions, path_patterns = [], path_unpatterns = [],
             if aop.isref() and basepath not in refhistos:
                 ao.setPath(aop.varpath(keep_prefix=False, defaultvarid=defaultWeightName))
                 refhistos[basepath] = ao
+                if basepath and basepath not in hpaths:
+                    hpaths.append(basepath)
             else: #if basepath not in mchistos[infile]:
                 mchistos[inname].setdefault(basepath_with_anaopts, {})[aop.varid(defaultWeightName)] = ao
                 if basepath and basepath not in hpaths:
@@ -152,7 +154,7 @@ def _get_histos(filelist, plotoptions, path_patterns = [], path_unpatterns = [],
     return refhistos, mchistos, hpaths
 
 
-def _add_ref_hist(output, refhisto, reftitle, ratiolabel, keepOverflows):
+def _add_ref_hist(output, refhisto, reftitle, keepOverflows):
     refhisto.setAnnotation('IsRef', True)
     # assemble array of REF/REF2/... for every reference curve tag on
     # the command line, sort them based on tailing digits, then loop
@@ -178,11 +180,6 @@ def _add_ref_hist(output, refhisto, reftitle, ratiolabel, keepOverflows):
             bandao = yoda.plotting.utils.mkPlotFriendlyScatter(refhisto,includeOverflows=keepOverflows,errorPattern=errpat)
             output['histograms'][reflabel]['BandUncertainty'] = bandao
 
-    # decide if ratio panel is shown or not
-    output['plot features']['RatioPlot'] = ratiolabel != None
-    # set label on y-axis of the ratio panel
-    output['plot features']['RatioPlotYLabel'] = ratiolabel
-
 
 def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptions,
                  style, rc_params, mc_errs, nRatioTicks, showWeights, removeOptions, deviation,
@@ -243,20 +240,29 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
         if re.fullmatch(r"REF(\d+)?$", key):
             outputdict[key] = val
 
+    # decide if ratio panel is shown or not, the hierarchy is as follows:
+    # 1. if --no-ratio was explicitly passed, it always wins
+    # 2. if RatioPlot was explicitly given in the plot file, use it
+    # 3. otherwise check if the ref histo was annotated with RatioPlot
+    # 4. else assume the user wants the ratio panel
+    ratio_default = refhistos[plot_id].annotation('RatioPlot', True) if plot_id in refhistos else True
+    outputdict['plot features'].setdefault('RatioPlot', ratio_default)
+    # apply command-line overwrite if applicable
+    if showRatio != None:  outputdict['plot features']['RatioPlot'] = showRatio
+
     keepOverflows = int(outputdict['plot features'].get('IncludeOverflows', '0'))
 
     # Check if there's reference data
     if plot_id in refhistos and rpmode != 'datamc':
         # Adding it first ensures it goes in the denominator
-        rplabel = None
-        hasRatio = showRatio if showRatio != None else refhistos[plot_id].annotation('RatioPlot', True)
-        if hasRatio:
+        if outputdict['plot features']['RatioPlot']:
             rplabel = ratioPlotLabel if ratioPlotLabel != None else \
                       refhistos[plot_id].annotation('RatioPlotYLabel', 'MC/Data')
+            outputdict['plot features']['RatioPlotYLabel'] = rplabel
         reftitle = refLabel if refLabel != None else \
                    refhistos[plot_id].annotation('Title', 'Data')
         reflabel = reftitle if reftitle != None else 'Data'
-        _add_ref_hist(outputdict, refhistos[plot_id], reflabel, rplabel, keepOverflows)
+        _add_ref_hist(outputdict, refhistos[plot_id], reflabel, keepOverflows)
 
     # Now add MC curves
     lhapdfCheck = True
@@ -272,7 +278,7 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
             thisFilePlotOptions = dict(plotoptions.get(filename, {}))
 
             # add options string to legend entry
-            newtitle = thisFilePlotOptions.get('Title', '')
+            newtitle = str(thisFilePlotOptions.get('Title', ''))
             if not removeOptions:
                 newtitle += label
             thisFilePlotOptions['Title'] = newtitle
@@ -426,15 +432,15 @@ def _make_output(plot_id, plotdirs, config_files, mchistos, refhistos, plotoptio
     # Check if there's reference data
     if plot_id in refhistos and rpmode == 'datamc':
         # Adding it last ensures it goes in the numerator
-        rplabel = None
-        hasRatio = showRatio if showRatio != None else refhistos[plot_id].annotation('RatioPlot', True)
-        if hasRatio:
+        if outputdict['plot features']['RatioPlot']:
             rplabel = ratioPlotLabel if ratioPlotLabel != None else \
                       refhistos[plot_id].annotation('RatioPlotYLabel', 'Data/MC')
+            outputdict['plot features']['RatioPlotYLabel'] = rplabel
         reftitle = refLabel if refLabel != None else \
                    refhistos[plot_id].annotation('Title', 'Data')
         reflabel = reftitle if reftitle != None else 'Data'
-        _add_ref_hist(outputdict, refhistos[plot_id], reflabel, rplabel, keepOverflows)
+        _add_ref_hist(outputdict, refhistos[plot_id], reflabel, keepOverflows)
+        # set label on y-axis of the ratio panel
 
     # Remove all sections of the output_dict that do not contain any information.
     # A list of keys is first created. Otherwise, it will raise an error since the size of the dict changes.
