@@ -107,6 +107,10 @@ namespace Rivet {
     return handler().numEvents();
   }
 
+  double Analysis::effNumEvents() const {
+    return handler().effNumEvents();
+  }
+
   double Analysis::sumW() const {
     return handler().sumW();
   }
