@@ -52,6 +52,7 @@ namespace Rivet {
       _customDefaultWeightIdx(-1),
       _dumpPeriod(0), _dumping(false) {
     registerDefaultTypes<double,int,string>();
+    _beaminfo = make_shared<YODA::BinnedEstimate<string>>("/TMP/_BEAMPZ");
   }
 
 
@@ -118,7 +119,7 @@ namespace Rivet {
     // Set the Run's beams based on this first event
     /// @todo Improve this const ugliness
     const Event evt(const_cast<GenEvent&>(ge), _weightIndices);
-    setRunBeams(Rivet::beams(evt));
+    if (_checkBeams)  setRunBeams(Rivet::beams(evt));
 
     MSG_DEBUG("Initialising the analysis handler");
     _eventNumber = ge.event_number();
@@ -746,7 +747,7 @@ namespace Rivet {
                       << " and may be ignored in the analysis.");
         opts[opt[0]] = opt[1];
       }
-      for ( auto opt: opts) {
+      for (const auto& opt: opts) {
         analysis->_options[opt.first] = opt.second;
         analysis->_optstring += ":" + opt.first + "=" + opt.second;
       }
@@ -756,6 +757,9 @@ namespace Rivet {
           return *this;
         }
       }
+      if (analysis->name() != analysisname) {
+        MSG_WARNING("Options reordered to use canonical analysis name '" << analysis->name() << "'");
+      }
       analysis->_analysishandler = this;
       _analyses[analysisname] = analysis;
     } else {
@@ -794,7 +798,9 @@ namespace Rivet {
                                    const vector<string> &addopts,
                                    const vector<string> &matches,
                                    const vector<string> &unmatches,
-                                   const bool equiv, const bool reentrantOnly) {
+                                   const bool equiv,
+                                   const bool reentrantOnly,
+                                   const bool checkbeams) {
 
     // Parse option adding.
     vector<string> optAnas;
@@ -860,7 +866,7 @@ namespace Rivet {
         YODA::read(file, aos_raw);
         for (YODA::AnalysisObject* aor : aos_raw) {
           const string& aopath = aor->path();
-          if (aopath == "/TMP/_BEAMPZ") {
+          if (checkbeams && aopath == "/TMP/_BEAMPZ") {
             raw_map[aopath].reset(aor);
             ++rawcount; ++tmpcount;
             continue;
