@@ -80,10 +80,6 @@ namespace Rivet {
     // Set current weight-scaling member
     _fileweight = weight;
 
-    // In case makeReader fails.
-    std::string errormessage;
-
-    #ifdef RIVET_ENABLE_HEPMC_3
     if (evtfile == "-") {
       #if HEPMC3_VERSION_CODE < 3003000
         // Turn off the buffering to make IO faster and make ungetc work on cin
@@ -91,9 +87,8 @@ namespace Rivet {
         #ifdef HAVE_LIBZ
         _istr = make_shared<zstr::istream>(std::ref(std::cin));
         #else
-        _istr = make_shared<std::istream>(std::ref(std::cin));
+        _istr = std::shared_ptr<std::istream>(&std::cin, [](auto*){ /* no deletion */ });
         #endif
-        // Use standard HepMC3 deduction on stream. For HepMC3 < 3.2.0 the function is implemented in Rivet
         _hepmcReader = RivetHepMC::deduce_reader(*_istr);
       #else
         _hepmcReader = RivetHepMC::deduce_reader(std::cin);
@@ -146,25 +141,11 @@ namespace Rivet {
       }
       if (!_istr) MSG_INFO("Info in deduce_reader: input stream is too short or invalid.");
       for (size_t i = 0; i < back; ++i) _istr->unget();
-      if (strncmp(head.at(0).c_str(), "HepMC::Version", 14) == 0 &&
-          strncmp(head.at(1).c_str(), "HepMC::CompressedAsciiv3-START_EVENT_LISTING", 44) == 0) {
-        MSG_INFO("Info in deduce_reader: Attempt CompressedAsciiv3");
-        //_hepmcReader= make_shared<Rivet::RivetHepMC::ReaderCompressedAscii>(_istr);
-      }
-      #endif
+    #endif
     }
-    #endif
 
-
-    #ifndef RIVET_ENABLE_HEPMC_3
-    // Use Rivet's own file format deduction (which uses the one in
-    // HepMC3 if needed).
-    _hepmcReader = HepMCUtils::makeReader(evtfile, _istr, &errormessage);
-
-    // Check that it worked.
-    #endif
     if (_hepmcReader == nullptr) {
-      MSG_ERROR("Read error in file '" << evtfile << "' " << errormessage);
+      MSG_ERROR("Read error in file '" << evtfile);
       return false;
     }
     return true;
@@ -172,48 +153,66 @@ namespace Rivet {
 
 
   bool Run::init(const std::string& evtfile, double weight) {
-    if (!openFile(evtfile, weight)) return false;
+    try {
+      if (!openFile(evtfile, weight)) return false;
 
-    // Read first event to define run conditions
-    bool ok = readEvent();
-    if (!ok) return false;
-    if(HepMCUtils::particles(_evt).size() == 0){
-      MSG_ERROR("Empty first event.");
-      return false;
-    }
-    _evtnumber = _evt->event_number(); // set first event number
-    _evtcount = 1; // first event used for initialisation
-
-    // Initialise AnalysisHandler with beam information from first event
-    _ah.init(*_evt);
-
-    // Set cross-section from command line
-    if (!std::isnan(_xs)) {
-      MSG_DEBUG("Setting user cross-section = " << _xs << " pb");
-      _ah.setCrossSection(make_pair(_xs, 0.0), true);
-    }
-
-    // List the chosen & compatible analyses if requested
-    if (_listAnalyses) {
-      for (const std::string& ana : _ah.analysisNames()) {
-        cout << ana << endl;
+      // Read first event to define run conditions
+      bool ok = readEvent();
+      if (!ok) return false;
+      if(HepMCUtils::particles(_evt).size() == 0) {
+        MSG_ERROR("Empty first event.");
+        return false;
       }
-    }
+      _evtnumber = _evt->event_number(); // set first event number
+      _evtcount = 1; // first event used for initialisation
 
-    return true;
+      // Initialise AnalysisHandler with beam information from first event
+      _ah.init(*_evt);
+
+      // Set cross-section from command line
+      if (notNaN(_xs)) {
+        MSG_DEBUG("Setting user cross-section = " << _xs << " pb");
+        _ah.setCrossSection(make_pair(_xs, 0.0), true);
+      }
+
+      // List the chosen & compatible analyses if requested
+      if (_listAnalyses) {
+        for (const std::string& ana : _ah.analysisNames()) {
+          cout << ana << endl;
+        }
+      }
+
+      return true;
+    }
+    catch (const Error &err){
+      std::cerr << "Error in run initialisation: " << err.what();
+      exit(1);
+    }
   }
 
 
   bool Run::processEvent() {
-    _ah.analyze(*_evt);
-    return true;
+    try {
+      _ah.analyze(*_evt);
+      return true;
+    }
+    catch (const Error &err){
+      std::cerr << "Error in processing event: " << err.what();
+      exit(1);
+    }
   }
 
 
   bool Run::finalize() {
-    _evt.reset();
-    _ah.finalize();
-    return true;
+    try {
+      _evt.reset();
+      _ah.finalize();
+      return true;
+    }
+    catch (const Error &err){
+      std::cerr << "Error in run finalize: " << err.what();
+      exit(1);
+    }
   }
 
 
