@@ -27,12 +27,12 @@ namespace Rivet {
 
 namespace Rivet {
   void ChargedFinalState::project(const Event& e) {
-    const FinalState& fs = applyProjection<FinalState>(e, "FS");
+    const FinalState& fs = apply<FinalState>(e, "FS");
     // _theParticles.clear();
     // std::remove_copy_if(fs.particles().begin(), fs.particles().end(),
     //                     std::back_inserter(_theParticles),
     //                     [](const Rivet::Particle& p) { return p.charge3() == 0; });
-    _theParticles = filter_select(fs.particles(), isCharged);
+    _theParticles = select(fs.particles(), isCharged);
     MSG_DEBUG("Number of charged final-state particles = " << _theParticles.size());
     if (getLog().isActive(Log::TRACE)) {
       for (const Particle&  p : _theParticles) {
