@@ -15,7 +15,7 @@ namespace Rivet {
     else if (_boosttype == DISFrame::BREIT) hcmboost = diskin.boostBreit();
 
     const DISLepton& dislep = diskin.apply<DISLepton>(e, "Lepton");
-    if ( diskin.failed() ) {
+    if ( dislep.failed() ) {
       fail();
       return;
     }
@@ -25,7 +25,7 @@ namespace Rivet {
     // Fill the particle list with all particles _other_ than the DIS scattered
     // lepton, with momenta boosted into the appropriate frame.
     _theParticles.clear();
-    _theParticles.reserve(fs.particles().size()-1);
+    _theParticles.reserve(fs.particles().size());
     ConstGenParticlePtr dislepGP = dislep.out().genParticle();
     // const GenParticlePtr dislepIN = dislep.in().genParticle();
 
