@@ -28,7 +28,8 @@ namespace Rivet {
     ConstGenParticlePtr lep2 = gglep.out().second.genParticle();
     // Ensure that we skip the GammaGamma leptons
     for (const Particle& p : fs.particles()) {
-      if (p.genParticle() != lep1 && p.genParticle() != lep2)  _theParticles.push_back(p);
+      if (p.genParticle() != lep1 &&
+	  p.genParticle() != lep2)  _theParticles.push_back(p);
     }
   }
 
