@@ -17,7 +17,7 @@ namespace Rivet {
 
 
   void VisibleFinalState::project(const Event& e) {
-    const FinalState& fs = applyProjection<FinalState>(e, "FS");
+    const FinalState& fs = apply<FinalState>(e, "FS");
     _theParticles.clear();
     std::remove_copy_if(fs.particles().begin(), fs.particles().end(),
                         std::back_inserter(_theParticles), isInvisible);
@@ -25,4 +25,4 @@ namespace Rivet {
   }
 
 
-}
+}
\ No newline at end of file
