@@ -18,7 +18,10 @@ namespace Rivet {
     const string name2 = papername + ".yoda";
     const string path2 = findAnalysisRefFile(name2);
     if (!path2.empty()) return path2;
-    throw Rivet::Error("Couldn't find a ref data file '" + name1 + "' or '" + name2 + "' " +
+    const string name3 = papername + ".yoda.h5";
+    const string path3 = findAnalysisRefFile(name3);
+    if (!path3.empty()) return path3;
+    throw Rivet::Error("Couldn't find a ref data file '" + name1 + "', '" + name2 + "' or '" + name3 + "' " +
                        "in the path " + toString(getAnalysisRefPaths()) + " for analysis " + papername);
   }
 
